#
# spec file for package python-pydash
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-pydash
Version:        6.0.2
Release:        1.4
Summary:        The kitchen sink of Python functional utility libraries
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/dgilland/pydash
Source:         https://files.pythonhosted.org/packages/source/p/pydash/pydash-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
The kitchen sink of Python utility libraries for doing "stuff" in a functional way.
Based on the Lo-Dash Javascript library.

%prep
%setup -q -n pydash-%{version}
rm tox.ini

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
sed -i '/--.*cov/d' setup.cfg
%pytest tests/

%files %{python_files}
%doc AUTHORS.rst CHANGELOG.rst README.rst
%license LICENSE.rst
%{python_sitelib}/*

%changelog
* Mon Oct 16 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 6.0.2
  * Only prevent access to object paths containing ``__globals__`` or
    ``__builtins__`` instead of all dunder-methods for non-dict/list
    objects.
- from version 6.0.1
  * Fix exception raised due to mishandling of non-string keys in functions
    like ``get()`` for non-dict/list objects that used integer index references
    like ``"[0]"``.
- from version 6.0.0
  * Prevent access to object paths containing dunder-methods in functions like
    ``get()`` for non-dict/list objects. Attempting to access dunder-methods
    using get-path keys will raise a ``KeyError`` (e.g. ``get(SomeClass(),
    '__init__'`` will raise). Access to dict keys are unaffected (e.g.
    ``get({"__init__": True}, "__init__")`` will return ``True``).
    (**breaking change**)
  * Add support for Python 3.11.
  * Drop support for Python 3.6 (**breaking change**)
- from version 5.1.2
  * Remove unnecessary type check and conversion for ``exceptions``
    argument in ``pydash.retry``.
- from version 5.1.1
  * Add support for Python 3.10.
  * Fix timing assertion issue in test for ``pydash.delay`` where it could
    fail on certain environments.
- Switch build system from setuptools to pyproject.toml
- Update BuildRequires from pyproject.toml
* Thu Apr  7 2022 pgajdos@suse.com
- version update to 5.1.0
  v5.1.0 (2021-10-02)
  - ------------------
  - Support matches-style callbacks on non-dictionary objects that are compatible with ``pydash.get`` in functions like ``pydash.find``.
  v5.0.2 (2021-07-15)
  - ------------------
  - Fix compatibility issue between ``pydash.py_`` / ``pydash._`` and ``typing.Protocol`` + ``typing.runtime_checkable``
    that caused an exception to be raised for ``isinstance(py_, SomeRuntimeCheckableProtocol)``.
  v5.0.1 (2021-06-27)
  - ------------------
  - Fix bug in ``merge_with`` that prevented custom iteratee from being used when recursively merging. Thanks weineel_!
  v5.0.0 (2021-03-29)
  - ------------------
  - Drop support for Python 2.7. (**breaking change**)
  - Improve Unicode word splitting in string functions to be inline with Lodash. Thanks mervynlee94_! (**breaking change**)
  - ``camel_case``
  - ``human_case``
  - ``kebab_case``
  - ``lower_case``
  - ``pascal_case``
  - ``separator_case``
  - ``slugify``
  - ``snake_case``
  - ``start_case``
  - ``upper_case``
  - Optimize regular expression constants used in ``pydash.strings`` by pre-compiling them to regular expression pattern objects.
  v4.9.3 (2021-03-03)
  - ------------------
  - Fix regression introduced in ``v4.8.0`` that caused ``merge`` and ``merge_with`` to raise an exception when passing ``None``
    as the first argument.
  v4.9.2 (2020-12-24)
  - ------------------
  - Fix regression introduced in ``v4.9.1`` that broke ``pydash.get`` for dictionaries and dot-delimited keys that reference
    integer dict-keys.
  v4.9.1 (2020-12-14)
  - ------------------
  - Fix bug in ``get/has`` that caused ``defaultdict`` objects to get populated on key access.
  v4.9.0 (2020-10-27)
  - ------------------
  - Add ``default_to_any``. Thanks gonzalonaveira_!
  - Fix mishandling of key names containing ``\.`` in ``set_``, ``set_with``, and ``update_with`` where the ``.`` was not
    treated as a literal value within the key name. Thanks zhaowb_!
- python-mock is not required for build
* Fri Jul 24 2020 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
- Update to v4.8.0
* Thu Jan  9 2020 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v4.7.6
